@@ -10,11 +10,13 @@
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QQmlContext>
+#include <QQuickStyle>
 
 #include <KAboutData>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
+#include "about.h"
 #include "historymanager.h"
 #include "mathengine.h"
 #include "inputmanager.h"
@@ -23,7 +25,17 @@
 
 int main(int argc, char *argv[])
 {
+    // set default style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+    // if using org.kde.desktop, ensure we use kde style if possible
+    if (qEnvironmentVariableIsEmpty("QT_QPA_PLATFORMTHEME")) {
+        qputenv("QT_QPA_PLATFORMTHEME", "kde");
+    }
+
     QCommandLineParser parser;
+
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
 
@@ -46,12 +58,13 @@ int main(int argc, char *argv[])
 
     parser.process(app);
 
+    qmlRegisterSingletonInstance("org.kde.kalk", 1, 0, "AboutType", &AboutType::instance());
+
 #ifdef QT_DEBUG
     engine.rootContext()->setContextProperty(QStringLiteral("debug"), true);
 #else
     engine.rootContext()->setContextProperty(QStringLiteral("debug"), false);
 #endif
-    engine.rootContext()->setContextProperty(QStringLiteral("kalkAboutData"), QVariant::fromValue(aboutData));
     // load main ui
     engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
 
